@@ -13,10 +13,14 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import os
+
 import keystonemiddleware.auth_token
+from oslo_config import cfg
 from oslo_log import log
 from oslo_policy import policy
 from oslo_utils import importutils
+from paste import deploy
 import pecan
 import webob.exc
 from werkzeug import serving
@@ -77,10 +81,24 @@ class NotImplementedMiddleware(object):
                 "not implement this feature 😞")
 
 
-def setup_app(config=PECAN_CONFIG, cfg=None):
+def load_app(conf, appname=None):
+    # Build the WSGI app
+    cfg_path = conf.api.paste_config
+    if not os.path.isabs(cfg_path):
+        cfg_path = conf.find_file(cfg_path)
+
+    if cfg_path is None or not os.path.exists(cfg_path):
+        raise cfg.ConfigFilesNotFoundError([conf.api.paste_config])
+
+    LOG.info("WSGI config used: %s" % cfg_path)
+    return deploy.loadapp("config:" + cfg_path, name=appname)
+
+
+def setup_app(config=None, cfg=None):
     if cfg is None:
         # NOTE(jd) That sucks but pecan forces us to use kwargs :(
         raise RuntimeError("Config is actually mandatory")
+    config = config or PECAN_CONFIG
     s = config.get('storage')
     if not s:
         s = storage.get_driver(cfg)
@@ -127,8 +145,29 @@ def setup_app(config=PECAN_CONFIG, cfg=None):
     return app
 
 
+class WerkzeugApp(object):
+    # NOTE(sileht): The purpose of this class is only to be used
+    # with werkzeug to create the app after the werkzeug
+    # fork gnocchi-api and avoid creation of connection of the
+    # storage/indexer by the main process.
+
+    def __init__(self, conf):
+        self.app = None
+        self.conf = conf
+
+    def __call__(self, environ, start_response):
+        if self.app is None:
+            self.app = load_app(self.conf)
+        return self.app(environ, start_response)
+
+
 def build_server():
     conf = service.prepare_service()
     serving.run_simple(conf.api.host, conf.api.port,
-                       setup_app(cfg=conf),
+                       WerkzeugApp(conf),
                        processes=conf.api.workers)
+
+
+def app_factory(global_config, **local_conf):
+    cfg = service.prepare_service()
+    return setup_app(None, cfg=cfg)
