@@ -74,19 +74,18 @@ class CephStorage(_carbonara.CarbonaraBasedStorage):
             self.MEASURE_PREFIX,
             str(metric.id),
             str(uuid.uuid4()),
-            datetime.datetime.utcnow().strftime("%Y%M%d_%H:%M:%S")))
+            datetime.datetime.utcnow().strftime("%Y%m%d_%H:%M:%S")))
         with self._get_ioctx() as ioctx:
             ioctx.write_full(name, data)
             ioctx.set_xattr(self.MEASURE_PREFIX, name, "")
 
-    @classmethod
-    def _list_object_names_to_process(cls, ioctx, prefix=None):
+    def _list_object_names_to_process(self, ioctx, prefix=None):
         try:
-            xattrs_iterator = ioctx.get_xattrs(cls.MEASURE_PREFIX)
+            xattrs = ioctx.get_xattrs(self.MEASURE_PREFIX)
         except rados.ObjectNotFound:
             return []
-        return [name for name, __ in xattrs_iterator
-                if prefix is None or name.startswith(prefix)]
+        return set(name for name, __ in xattrs
+                   if prefix is None or name.startswith(prefix))
 
     def _pending_measures_to_process_count(self, metric_id):
         with self._get_ioctx() as ioctx:
@@ -105,8 +104,12 @@ class CephStorage(_carbonara.CarbonaraBasedStorage):
             object_names = self._list_object_names_to_process(ctx,
                                                               object_prefix)
             for n in object_names:
-                ctx.rm_xattr(self.MEASURE_PREFIX, n)
-                ctx.remove_object(n)
+                try:
+                    ctx.rm_xattr(self.MEASURE_PREFIX, n)
+                    ctx.remove_object(n)
+                except rados.ObjectNotFound:
+                    # Another worker may have removed it, don't worry.
+                    pass
 
     @contextlib.contextmanager
     def _process_measure_for_metric(self, metric):
